@@ -30,6 +30,15 @@ sub run
   my %types = (
     swf   => 'application/x-shockwave-flash',
     xml   => 'text/xml',
+    jpg   => 'image/jpeg',
+    jpeg  => 'image/jpeg',
+    png   => 'image/png',
+    bmp   => 'image/bmp',
+    gif   => 'image/gif',
+    json  => 'application/x-json',
+    css   => 'text/css',
+    pdf   => 'application/x-pdf',
+    js    => 'text/javascript',
   );
   my $type = $types{lc($ext)} || 'application/octet-stream';
   $Response->ContentType( $type );
